export const ConnectorSchemaTemplate = `import * as zod from "zod";

import { type SmartFormFieldsMetadata } from "@netlify/sdk/ui/react/components";

// This is an example schema, see https://developers.netlify.com/sdk/connectors/develop/configuration-options/#option-properties for more information.
export const ConnectorConfigurationSchema = zod.object({
  apiUrl: zod.string().trim().min(1).default("https://api.example.com"),
  apiToken: zod.string().trim().min(1).default("exampleToken"),
  // The instanceID field is needed for additional Connect features
  instanceID: zod.string().optional()
});

export const configFieldsMeta: SmartFormFieldsMetadata = {
  apiUrl: {
    label: "API URL",
    helpText: "The URL of the API to connect to",
  },
  apiToken: {
    label: "API Token",
    helpText: "The token to authenticate with the API",
    secret: true
  },
  instanceID: {
    label: "Instance ID",
    helpText: "The ID of the instance to connect to",
  },
};

export type ConnectorSettings = Zod.output<typeof ConnectorConfigurationSchema>;`;
