// https://github.com/microsoft/TypeScript/blob/b9d96df/src/lib/esnext.promise.d.ts#L16
export interface PromiseWithResolvers<T> {
  promise: Promise<T>;
  resolve: (value: T | PromiseLike<T>) => void;

  reject: (reason?: any) => void;
}

/**
 * `promiseWithResolvers` is a polyfill for Promise#withResolvers.
 *
 * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Promise/withResolvers
 */
export const promiseWithResolvers = <T>(): PromiseWithResolvers<T> => {
  // @ts-expect-error: Ssh, we're about to add properties to this object
  const result: PromiseWithResolvers<T> = {};
  result.promise = new Promise((resolve_, reject_) => {
    result.resolve = resolve_;
    result.reject = reject_;
  });
  return result;
};
